Stats Module
=================

.. automodule:: stats
   :members:
   
   .. autosummary::
     
      to_heatmap_custom
      to_image_custom
      friedman_shaffer_scmamp
      determine_color
      format_text
      friedman_dunn_test
      friedman_nemenyi_test
